@@ -313,6 +313,7 @@ def download(identifier,
              ignore_errors=None,
              on_the_fly=None,
              return_responses=None,
+             no_change_timestamp=None,
              **get_item_kwargs):
     """Download files from an item.
 
@@ -390,7 +391,8 @@ def download(identifier,
                       item_index=item_index,
                       ignore_errors=ignore_errors,
                       on_the_fly=on_the_fly,
-                      return_responses=return_responses)
+                      return_responses=return_responses,
+                      no_change_timestamp=no_change_timestamp)
     return r
 
 
@@ -447,52 +449,28 @@ def delete(identifier,
 
 
 def get_tasks(identifier=None,
-              task_id=None,
-              task_type=None,
               params=None,
               config=None,
               config_file=None,
-              verbose=None,
               archive_session=None,
               http_adapter_kwargs=None,
               request_kwargs=None):
-    """Get tasks from the Archive.org catalog. ``internetarchive`` must be configured
-    with your logged-in-* cookies to use this function. If no arguments are provided,
-    all queued tasks for the user will be returned.
+    """Get tasks from the Archive.org catalog.
 
     :type identifier: str
     :param identifier: (optional) The Archive.org identifier for which to retrieve tasks
                        for.
 
-    :type task_id: int or str
-    :param task_is: (optional) The task_id to retrieve from the Archive.org catalog.
-
-    :type task_type: str
-    :param task_type: (optional) The type of tasks to retrieve from the Archive.org
-                      catalog. The types can be either "red" for failed tasks, "blue" for
-                      running tasks, "green" for pending tasks, "brown" for paused tasks,
-                      or "purple" for completed tasks.
-
     :type params: dict
     :param params: (optional) The URL parameters to send with each request sent to the
                    Archive.org catalog API.
 
-    :type config: dict
-    :param secure: (optional) Configuration options for session.
-
-    :type verbose: bool
-    :param verbose: (optional) Set to ``True`` to retrieve verbose information for each
-                    catalog task returned. verbose is set to ``True`` by default.
-
     :returns: A set of :class:`CatalogTask` objects.
     """
     if not archive_session:
         archive_session = get_session(config, config_file, http_adapter_kwargs)
     return archive_session.get_tasks(identifier=identifier,
-                                     task_id=task_id,
                                      params=params,
-                                     config=config,
-                                     verbose=verbose,
                                      request_kwargs=request_kwargs)
 
 
@@ -560,7 +538,7 @@ def search_items(query,
                                         max_retries=max_retries)
 
 
-def configure(username=None, password=None, config_file=None):
+def configure(username=None, password=None, config_file=None, host=None):
     """Configure internetarchive with your Archive.org credentials.
 
     :type username: str
@@ -575,7 +553,8 @@ def configure(username=None, password=None, config_file=None):
     """
     username = input('Email address: ') if not username else username
     password = getpass('Password: ') if not password else password
-    config_file_path = config_module.write_config_file(username, password, config_file)
+    config_file_path = config_module.write_config_file(
+        username, password, config_file, host)
     return config_file_path
 
 
